# Generated by Django 3.0.1 on 2020-03-30 21:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('queryset_reporter', '0003_auto_20191029_1842'),
    ]

    operations = [
        migrations.AlterField(
            model_name='queryset',
            name='model',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType', verbose_name='Modelo'),
        ),
    ]
